@@ -1,9 +1,9 @@
 import unittest
 import numpy as np
 try:
-    from .fit import *
-except ImportError:
     from fit import *
+except ImportError:
+    from pyees.fit import *
 
 
 class test(unittest.TestCase):
@@ -38,7 +38,7 @@ class test(unittest.TestCase):
         Fb = F.popt[1]
 
         self.assertAlmostEqual(Fa.value, 2)
-        self.assertEqual(str(Fa.unit), 'DELTAC/m')
+        self.assertEqual(str(Fa.unit), 'C/m')
         self.assertAlmostEqual(Fa.uncert, 0)
 
         self.assertAlmostEqual(Fb.value, 10)
@@ -65,11 +65,11 @@ class test(unittest.TestCase):
         Fc = F.popt[2]
 
         self.assertAlmostEqual(Fa.value, 2)
-        self.assertEqual(str(Fa.unit), 'DELTAC/m2')
+        self.assertEqual(str(Fa.unit), 'C/m2')
         self.assertAlmostEqual(Fa.uncert, 0)
 
         self.assertAlmostEqual(Fb.value, 10)
-        self.assertEqual(str(Fb.unit), 'DELTAC/m')
+        self.assertEqual(str(Fb.unit), 'C/m')
         self.assertAlmostEqual(Fb.uncert, 0)
 
         self.assertAlmostEqual(Fc.value, 15)
@@ -98,15 +98,15 @@ class test(unittest.TestCase):
         Fd = F.popt[3]
 
         self.assertAlmostEqual(Fa.value, 2)
-        self.assertEqual(str(Fa.unit), 'DELTAC/m3')
+        self.assertEqual(str(Fa.unit), 'C/m3')
         self.assertAlmostEqual(Fa.uncert, 0)
 
         self.assertAlmostEqual(Fb.value, 10)
-        self.assertEqual(str(Fb.unit), 'DELTAC/m2')
+        self.assertEqual(str(Fb.unit), 'C/m2')
         self.assertAlmostEqual(Fb.uncert, 0)
 
         self.assertAlmostEqual(Fc.value, 15)
-        self.assertEqual(str(Fc.unit), 'DELTAC/m')
+        self.assertEqual(str(Fc.unit), 'C/m')
         self.assertAlmostEqual(Fc.uncert, 0)
 
         self.assertAlmostEqual(Fd.value, 50)
